# README.md
To install:
1. run shell script install_botohelper
2. setup the local_settings.py file according to what the install script tells you
3. run any of the other shell scripts in the root of the repo with -h to see what they do

